package com.soss.web.controller.coupon;


import com.soss.common.annotation.Log;
import com.soss.common.core.controller.BaseController;
import com.soss.common.core.domain.AjaxResult;
import com.soss.common.enums.BusinessType;
import com.soss.system.domain.CouponCategory;
import com.soss.system.service.ICouponCategoryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 优惠券类别 前端控制器
 * </p>
 *
 * @author caiyt
 * @since 2022-07-21
 */
@RestController
@RequestMapping("/coupon-category")
@Api("优惠券类别服务类")
public class CouponCategoryController extends BaseController {
    @Autowired
    private ICouponCategoryService couponCategoryService;

    /**
     * 新增优惠券类别
     */
    @PreAuthorize("@ss.hasPermi('coupon:category:add')")
    @Log(title = "新增优惠券类别", businessType = BusinessType.INSERT)
    @PutMapping
    @ApiOperation("新增优惠券类别")
    public AjaxResult add(@RequestBody CouponCategory couponCategory) {
        couponCategoryService.insertCouponCategory(couponCategory);
        return AjaxResult.success();
    }

    /**
     * 查询优惠券类别列表
     */
    @PreAuthorize("@ss.hasPermi('coupon:category:list')")
    @Log(title = "查询优惠券类别列表", businessType = BusinessType.INSERT)
    @GetMapping
    @ApiOperation("查询优惠券类别列表")
    public AjaxResult listCouponCategory(@RequestBody CouponCategory couponCategory) {
        List<CouponCategory> couponCategories = couponCategoryService.listCouponCategory(couponCategory);
        return AjaxResult.success(couponCategories);
    }

    /**
     * 变更优惠券类别状态
     */
    @PreAuthorize("@ss.hasPermi('coupon:category:state-switch')")
    @Log(title = "变更优惠券类别状态", businessType = BusinessType.INSERT)
    @GetMapping("/{id}/{state}")
    @ApiOperation(value = "变更优惠券类别状态", notes = "state: 状态 0 默认 1 生效 2 下线 3删除")
    public AjaxResult switchState(@PathVariable Integer id, @PathVariable Integer state) {
        int updateCnt = couponCategoryService.switchState(id, state);
        return toAjax(updateCnt);
    }
}
