package com.soss.system.service.impl;

import com.soss.common.enums.CouponCategoryType;
import com.soss.system.domain.CouponCategory;
import com.soss.system.mapper.CouponCategoryMapper;
import com.soss.system.mapper.CouponMapper;
import com.soss.system.service.ICouponCategoryService;
import io.jsonwebtoken.lang.Assert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 优惠券类别 服务实现类
 * </p>
 *
 * @author caiyt
 * @since 2022-07-21
 */
@Service
public class CouponCategoryServiceImpl implements ICouponCategoryService {
    @Autowired
    private CouponCategoryMapper couponCategoryMapper;
    @Autowired
    private CouponMapper couponMapper;

    /**
     * 新增优惠券类别
     *
     * @param couponCategory 优惠券类别
     * @return 结果
     */
    @Override
    @Transactional
    public void insertCouponCategory(CouponCategory couponCategory) {
        Assert.notNull(couponCategory.getName(), "优惠券类别名称还未填写");
        Assert.notNull(couponCategory.getType(), "优惠券类别的折扣形式还未选择");
        LocalDateTime now = LocalDateTime.now();
        couponCategory.setCreatedAt(now);
        couponCategory.setUpdatedAt(now);
        couponCategoryMapper.insertCouponCategory(couponCategory);
    }

    /**
     * 查询优惠券类别列表
     *
     * @param couponCategory 优惠券类别
     * @return 优惠券类别
     */
    @Override
    public List<CouponCategory> listCouponCategory(CouponCategory couponCategory) {
        List<CouponCategory> couponCategories = couponCategoryMapper.listCouponCategory(couponCategory);
        List<Integer> categoryIds = couponCategories.stream().map(CouponCategory::getId).collect(Collectors.toList());
        List<CouponCategory> couponCategoryCountList = couponMapper.getCouponCategoryTypeStat(categoryIds);
        Map<Integer, Long> countMap = couponCategoryCountList.stream()
                .collect(Collectors.toMap(CouponCategory::getId, CouponCategory::getCouponCnt));
        for (CouponCategory category : couponCategories) {
            category.setTypeDesc(CouponCategoryType.getDesc(category.getType()));
            Long count = countMap.get(category.getId());
            category.setCouponCnt(count == null ? 0L : count);
        }
        return couponCategories;
    }

    /**
     * 更新优惠券类别状态
     *
     * @param id
     * @param state
     * @return
     */
    @Override
    @Transactional
    public int switchState(Integer id, Integer state) {
        CouponCategory online = new CouponCategory(id, state);
        int updateCnt = couponCategoryMapper.updateCouponCategory(online);
        return updateCnt;
    }
}
